/*
 * FILE:
 *   freetype_ttf_loader.hpp
 *
 * PURPOSE:
 *   This implementation of TTFLoader uses Freetype to render a TTF
 *   font file into a bitmap, then returns a corresponding BitmapFont
 *   object. Kerning and anti-aliasing are supported via the new
 *   BitmapFont interface.
 *
 * AUTHOR:
 *   Stephen Thompson <stephen@solarflare.org.uk>
 *
 * CREATED:
 *   21-May-2012
 *   
 * COPYRIGHT:
 *   Copyright (C) Stephen Thompson, 2012 - 2024.
 *
 *   This file is part of the "Coercri" software library. Usage of "Coercri"
 *   is permitted under the terms of the Boost Software License, Version 1.0, 
 *   the text of which is displayed below.
 *
 *   Boost Software License - Version 1.0 - August 17th, 2003
 *
 *   Permission is hereby granted, free of charge, to any person or organization
 *   obtaining a copy of the software and accompanying documentation covered by
 *   this license (the "Software") to use, reproduce, display, distribute,
 *   execute, and transmit the Software, and to prepare derivative works of the
 *   Software, and to permit third-parties to whom the Software is furnished to
 *   do so, all subject to the following:
 *
 *   The copyright notices in the Software and this entire statement, including
 *   the above license grant, this restriction and the following disclaimer,
 *   must be included in all copies of the Software, in whole or in part, and
 *   all derivative works of the Software, unless such copies or derivative
 *   works are solely in the form of machine-executable object code generated by
 *   a source language processor.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 *   SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 *   FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *   DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef COERCRI_FREETYPE_TTF_LOADER
#define COERCRI_FREETYPE_TTF_LOADER

#include "ttf_loader.hpp"

namespace Coercri {

    class GfxDriver;

    class FreetypeTTFLoader : public TTFLoader {
    public:
        explicit FreetypeTTFLoader(boost::shared_ptr<GfxDriver> driver);
        virtual boost::shared_ptr<Font> loadFont(boost::shared_ptr<std::istream> str, int size);

    private:
        boost::shared_ptr<Coercri::GfxDriver> gfx_driver;
    };

}

#endif
